pub struct ExportProject {
pub name: String,
pub version: Option<String>,
}Expand description
Project metadata relevant to an export.
Fields
name: StringProject name, used as the default namespace and chart name.
version: Option<String>Free-form project version, used as the default chart version.