ExportError

Enum ExportError 

pub enum ExportError {
    Spec {
        resource: String,
        source: SpecError,
    },
    Unsupported {
        resource: String,
        target: &'static str,
        reason: String,
    },
}
Errors raised while lowering a manifest or emitting artifacts.

Variants



Spec

Resolving a manifest resource into a container specification failed during lowering.

Fields

resource: String

Resource whose resolution failed.

source: SpecError

Underlying specification error.



Unsupported

An emitter could not represent a resource for its target (for example, a locally built image has no registry reference to put in a Kubernetes manifest).

Fields

resource: String

Resource that cannot be represented.

target: &'static str

Target that rejected it.

reason: String

Why the resource is unsupported for this target.